# harborapi.ext.api

The `harborapi.ext.api` module contains helper functions for performing common tasks with the Harbor API that are not included in the API spec, such as fetching all vulnerabilities for all artifacts in one or more projects or repositories, fetching all repositories in one or more projects, etc. These functions are implemented using the standard endpoint methods from `harborapi.HarborAsyncClient`.

::: harborapi.ext.api
    options:
        merge_init_into_class: false
        show_if_no_docstring: true
        show_source: true
        show_bases: true
        <!-- members:
            - __init__ -->
